#include "dialogimpl.h"
//
DialogImpl::DialogImpl( QWidget * parent, Qt::WFlags f) 
	: QDialog(parent, f)
{
	setupUi(this);
    
    stack->setCurrentIndex( 0 );
    stackReceive->setCurrentIndex( 0 );
    comboReceiveAccountType->setCurrentIndex( 2 );
    sameSettingsChanged( true );
    
    connect( buttonPrevious, SIGNAL(clicked()), SLOT(movePrevious()) );
    connect( buttonNext, SIGNAL(clicked()), SLOT(moveNext()) );
    
    connect( checkSendUseSameSettings, SIGNAL(toggled(bool)), SLOT(sameSettingsChanged(bool)));
    
    connect( comboReceiveAuthenticationType, SIGNAL(currentIndexChanged(int)), SLOT(receiveAuthenticationChanged(int)) );
    connect( comboReceiveEncryptionType, SIGNAL(currentIndexChanged(int)), SLOT(receiveEncryptionChanged(int)) );
    connect( textReceiveHost, SIGNAL(textChanged(const QString &)), SLOT(receiveHostChanged(const QString &)) );
    connect( comboReceiveAccountType, SIGNAL(currentIndexChanged(int)), SLOT(receiveAccountTypeChanged(int)) );
    
    connect( textReceiveLogin, SIGNAL(textChanged(const QString &)), SLOT(receiveLoginChanged(const QString &)) );
    connect( textReceivePassword, SIGNAL(textChanged(const QString &)), SLOT(receivePasswordChanged(const QString &)) );
}
//
QString DialogImpl::getDefaultPort( const QString &protocol, const QString &auth )
{
    if( protocol == "POP3" )
    {
        if( auth == "SSL" )
        {
            return "995";
        }
        else
        {
            return "110";
        }
    }
    else if( protocol == "IMAP" || protocol == "Disconnected IMAP" )
    {
        if( auth == "SSL" )
        {
            return "993";
        }
        else
        {
            return "143";
        }
    }
    else if( protocol == "SMTP" )
    {
        if( auth == "SSL" )
        {
            return "465";
        }
        else
        {
            return "25";
        }
    }
    return "";
}


void DialogImpl::movePrevious()
{
    stack->setCurrentIndex( stack->currentIndex() - 1 );
    
    buttonPrevious->setEnabled( stack->currentIndex() == 0 ? false : true );
    buttonFinish->setEnabled( false );
    buttonNext->setEnabled( true );
}

void DialogImpl::moveNext()
{
    stack->setCurrentIndex( stack->currentIndex() + 1 );
    
    buttonPrevious->setEnabled( true );

    if( stack->currentIndex() == 3 )
    {
        buttonFinish->setEnabled( true );
        buttonNext->setEnabled( false );
    }
}

void DialogImpl::receiveAuthenticationChanged(int index)
{
QString _protocol = comboReceiveAccountType->currentText();
QString _auth = comboReceiveAuthenticationType->currentText();

    textReceivePort->setText( getDefaultPort(_protocol, _auth) );
    textReceiveLogin->setEnabled( _auth == "None" ? false : true );
    textReceivePassword->setEnabled( _auth == "None" ? false : true );
    
    if(checkSendUseSameSettings->checkState() == Qt::Checked)
    {
        textSendPort->setText( getDefaultPort("SMTP", _auth) );
        comboSendAuthenticationType->setCurrentIndex( index );
    }
}

void DialogImpl::receiveEncryptionChanged(int index)
{
    if(checkSendUseSameSettings->checkState() == Qt::Checked)
    {
        comboSendEncryptionType->setCurrentIndex( index );
    }
}

void DialogImpl::receiveHostChanged(const QString &text)
{
int _index = text.indexOf( '.' );

    if(checkSendUseSameSettings->checkState() == Qt::Checked)
    {
        if( _index > -1 )
        {
            textSendHost->setText( QString( "smtp" ) + text.right( text.length() - _index ) );
        }
    }
}

void DialogImpl::receiveAccountTypeChanged(int index)
{
QString _protocol = comboReceiveAccountType->currentText();
QString _auth = comboReceiveAuthenticationType->currentText();

    switch( index )
    {
        case 0:
            stackReceive->setCurrentIndex( 1 );
            comboReceiveLocalLockingMethod->setEnabled( true );
            labelReceiveLocalLockingMethod->setEnabled( true );
            break;

        case 1:
            stackReceive->setCurrentIndex( 1 );
            comboReceiveLocalLockingMethod->setEnabled( false );
            labelReceiveLocalLockingMethod->setEnabled( false );
            break;

        case 2:
            stackReceive->setCurrentIndex( 0 );
            if( textReceiveHost->text() == "" || textReceiveHost->text() == "imap." || textReceiveHost->text() == "pop."  )
            {
                textReceiveHost->setText( "pop." );
                textReceivePort->setText( getDefaultPort(_protocol, _auth) );
            }
            break;

        case 3:
            stackReceive->setCurrentIndex( 0 );
            if( textReceiveHost->text() == "" || textReceiveHost->text() == "imap." || textReceiveHost->text() == "pop."  )
            {
                textReceiveHost->setText( "imap." );
                textReceivePort->setText( getDefaultPort(_protocol, _auth) );
            }
            break;

        case 4:
            stackReceive->setCurrentIndex( 0 );
            if( textReceiveHost->text() == "" || textReceiveHost->text() == "imap." || textReceiveHost->text() == "pop."  )
            {
                textReceiveHost->setText( "imap." );
                textReceivePort->setText( getDefaultPort(_protocol, _auth) );
            }
            break;
    }
}

void DialogImpl::sameSettingsChanged( bool enabled )
{
    textSendHost->setEnabled( !enabled );
    textSendPort->setEnabled( !enabled );
    comboSendAuthenticationType->setEnabled( !enabled );
    textSendLogin->setEnabled( !enabled );
    textSendPassword->setEnabled( !enabled );
    comboSendEncryptionType->setEnabled( !enabled );
    buttonSendCheckSecurity->setEnabled( !enabled );
}

void DialogImpl::receiveLoginChanged(const QString &text)
{
    if(checkSendUseSameSettings->checkState() == Qt::Checked)
    {
        textSendLogin->setText( text );
    }
}

void DialogImpl::receivePasswordChanged(const QString &text)
{
    if(checkSendUseSameSettings->checkState() == Qt::Checked)
    {
        textSendPassword->setText( text );
    }
}

